==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/SummaryDataDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SummaryDataDescription } from "./SummaryDataDescription";
/**
 * @hidden
 */
var SummaryDataDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SummaryDataDescriptionMetadata, _super);
    function SummaryDataDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SummaryDataDescriptionMetadata.b = function (a) {
        if (SummaryDataDescriptionMetadata.a == null) {
            SummaryDataDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SummaryDataDescriptionMetadata.c(SummaryDataDescriptionMetadata.a);
        }
        if (a.g(SummaryDataDescriptionMetadata.a)) {
            return;
        }
        a.s(SummaryDataDescriptionMetadata.a);
    };
    SummaryDataDescriptionMetadata.c = function (a) {
        a.item("SummaryName", "String");
        a.item("SummaryValueRef", "(w:SummaryValue,wf:SummaryValue)DataRef");
        a.item("SummaryOperand", "ExportedType:string:SummaryOperand");
        a.item("SummaryOperand@names", "Min;Max;Sum;Average;Count;Custom");
        a.item("FormattedText", "String");
        a.item("FormattedValue", "String");
    };
    SummaryDataDescriptionMetadata.d = function (a) {
        SummaryDataDescriptionMetadata.b(a);
        a.u("SummaryData", function () { return new SummaryDataDescription(); });
        a.t("SummaryData", SummaryDataDescriptionMetadata.a);
    };
    SummaryDataDescriptionMetadata.$t = markType(SummaryDataDescriptionMetadata, 'SummaryDataDescriptionMetadata');
    SummaryDataDescriptionMetadata.a = null;
    return SummaryDataDescriptionMetadata;
}(Base));
export { SummaryDataDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/SummaryDataDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SummaryDataDescription } from "./SummaryDataDescription";
/**
 * @hidden
 */
var SummaryDataDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SummaryDataDescriptionMetadata, _super);
    function SummaryDataDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SummaryDataDescriptionMetadata.b = function (a) {
        if (SummaryDataDescriptionMetadata.a == null) {
            SummaryDataDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SummaryDataDescriptionMetadata.c(SummaryDataDescriptionMetadata.a);
        }
        if (a.j(SummaryDataDescriptionMetadata.a)) {
            return;
        }
        a.y(SummaryDataDescriptionMetadata.a);
    };
    SummaryDataDescriptionMetadata.c = function (a) {
        a.item("SummaryName", "String");
        a.item("SummaryValueRef", "(w:SummaryValue,wf:SummaryValue)DataRef");
        a.item("SummaryOperand", "ExportedType:string:DataSourceSummaryOperand");
        a.item("SummaryOperand@names", "Min;Max;Sum;Average;Count;Custom");
        a.item("FormattedText", "String");
        a.item("FormattedValue", "String");
    };
    SummaryDataDescriptionMetadata.d = function (a) {
        SummaryDataDescriptionMetadata.b(a);
        a.aa("SummaryData", function () { return new SummaryDataDescription(); });
        a.z("SummaryData", SummaryDataDescriptionMetadata.a);
    };
    SummaryDataDescriptionMetadata.$t = markType(SummaryDataDescriptionMetadata, 'SummaryDataDescriptionMetadata');
    SummaryDataDescriptionMetadata.a = null;
    return SummaryDataDescriptionMetadata;
}(Base));
export { SummaryDataDescriptionMetadata };
